==> beast-privilege-api-2.6.6-20230316.084232-8-sources.jar: com/thebeastshop/privilege/cond/KeyMemberMemorialCond.java <==
package com.thebeastshop.privilege.cond;

import com.thebeastshop.common.BaseQueryCond;

import java.util.Date;
import java.util.List;

public class KeyMemberMemorialCond extends BaseQueryCond {
    private List<String> channelCodes;
    private String cellPhone;
    private Integer memberLevel;
    private Date startDate;
    private Date endDate;
    private Integer processStatus;
    private Integer isDataPerfect;
    private String nickName;
    private Integer channelChargeId;

    public List<String> getChannelCodes() {
        return channelCodes;
    }

    public void setChannelCodes(List<String> channelCodes) {
        this.channelCodes = channelCodes;
    }

    public String getCellPhone() {
        return cellPhone;
    }

    public void setCellPhone(String cellPhone) {
        this.cellPhone = cellPhone;
    }

    public Integer getMemberLevel() {
        return memberLevel;
    }

    public void setMemberLevel(Integer memberLevel) {
        this.memberLevel = memberLevel;
    }

    public Date getStartDate() {
        return startDate;
    }

    public void setStartDate(Date startDate) {
        this.startDate = startDate;
    }

    public Date getEndDate() {
        return endDate;
    }

    public void setEndDate(Date endDate) {
        this.endDate = endDate;
    }

    public Integer getProcessStatus() {
        return processStatus;
    }

    public void setProcessStatus(Integer processStatus) {
        this.processStatus = processStatus;
    }

    public Integer getIsDataPerfect() {
        return isDataPerfect;
    }

    public void setIsDataPerfect(Integer isDataPerfect) {
        this.isDataPerfect = isDataPerfect;
    }

    public String getNickName() {
        return nickName;
    }

    public void setNickName(String nickName) {
        this.nickName = nickName;
    }

    public Integer getChannelChargeId() {
        return channelChargeId;
    }

    public void setChannelChargeId(Integer channelChargeId) {
        this.channelChargeId = channelChargeId;
    }


}

==> beast-privilege-api-3.0.13-sources.jar: com/thebeastshop/privilege/cond/KeyMemberMemorialCond.java <==
package com.thebeastshop.privilege.cond;

import com.thebeastshop.common.BaseQueryCond;

import java.util.Date;
import java.util.List;

public class KeyMemberMemorialCond extends BaseQueryCond {
    private List<String> channelCodes;
    private String cellPhone;
    private Integer memberLevel;
    private Date startDate;
    private Date endDate;

    private List<Integer> statusList;

    private Integer isDataPerfect;
    private String nickName;
    private Integer channelChargeId;

    private Integer isEmptyRecord;

    private Integer innerRequiredQueryCustomTable;

    private String innerEndYear;

    public List<String> getChannelCodes() {
        return channelCodes;
    }

    public void setChannelCodes(List<String> channelCodes) {
        this.channelCodes = channelCodes;
    }

    public String getCellPhone() {
        return cellPhone;
    }

    public void setCellPhone(String cellPhone) {
        this.cellPhone = cellPhone;
    }

    public Integer getMemberLevel() {
        return memberLevel;
    }

    public void setMemberLevel(Integer memberLevel) {
        this.memberLevel = memberLevel;
    }

    public Date getStartDate() {
        return startDate;
    }

    public void setStartDate(Date startDate) {
        this.startDate = startDate;
    }

    public Date getEndDate() {
        return endDate;
    }

    public void setEndDate(Date endDate) {
        this.endDate = endDate;
    }

    public List<Integer> getStatusList() {
        return statusList;
    }

    public void setStatusList(List<Integer> statusList) {
        this.statusList = statusList;
    }

    public Integer getIsDataPerfect() {
        return isDataPerfect;
    }

    public void setIsDataPerfect(Integer isDataPerfect) {
        this.isDataPerfect = isDataPerfect;
    }

    public String getNickName() {
        return nickName;
    }

    public void setNickName(String nickName) {
        this.nickName = nickName;
    }

    public Integer getChannelChargeId() {
        return channelChargeId;
    }

    public void setChannelChargeId(Integer channelChargeId) {
        this.channelChargeId = channelChargeId;
    }


    public Integer getIsEmptyRecord() {
        return isEmptyRecord;
    }

    public void setIsEmptyRecord(Integer isEmptyRecord) {
        this.isEmptyRecord = isEmptyRecord;
    }

    public Integer getInnerRequiredQueryCustomTable() {
        return innerRequiredQueryCustomTable;
    }

    public void setInnerRequiredQueryCustomTable(Integer innerRequiredQueryCustomTable) {
        this.innerRequiredQueryCustomTable = innerRequiredQueryCustomTable;
    }

    public String getInnerEndYear() {
        return innerEndYear;
    }

    public void setInnerEndYear(String innerEndYear) {
        this.innerEndYear = innerEndYear;
    }

}
